==> aliyun-gateway-pop-0.2.9-beta-sources.jar: com/aliyun/sdk/gateway/pop/interceptor/response/TeaResponseInterceptor.java <==
package com.aliyun.sdk.gateway.pop.interceptor.response;

import com.aliyun.core.http.HttpResponse;
import com.aliyun.core.logging.ClientLogger;
import com.aliyun.core.utils.AttributeMap;
import com.aliyun.core.utils.BaseUtils;
import com.aliyun.core.utils.ParseUtil;
import com.aliyun.core.utils.StringUtils;
import com.aliyun.sdk.gateway.pop.exception.PopClientException;
import com.aliyun.sdk.gateway.pop.exception.PopServerException;
import darabonba.core.RequestStyle;
import darabonba.core.TeaRequest;
import darabonba.core.TeaResponse;
import darabonba.core.interceptor.InterceptorContext;
import darabonba.core.interceptor.ResponseInterceptor;
import darabonba.core.sse.Event;
import darabonba.core.sse.SSEHttpResponseHandler;
import darabonba.core.utils.CommonUtil;

import java.util.HashMap;
import java.util.Map;

public class TeaResponseInterceptor implements ResponseInterceptor {
    private final ClientLogger logger = new ClientLogger(PopResInterceptor.class);

    @Override
    public TeaResponse modifyResponse(InterceptorContext context, AttributeMap attributes) {
        logger.verbose("HttpResponse process begin.");
        HttpResponse httpResponse = context.httpResponse();
        TeaRequest request = context.teaRequest();
        TeaResponse teaResponse = new TeaResponse();
        teaResponse.setHttpResponse(httpResponse);
        teaResponse.setSuccess(CommonUtil.is2xx(httpResponse.getStatusCode()));
        if (CommonUtil.isNot2xx(httpResponse.getStatusCode())) {
            Map<String, Object> errMsg = new HashMap<>();
            errMsg.put("statusCode", httpResponse.getStatusCode());
            if (context.httpResponseHandler() != null && request.style().equals(RequestStyle.SSE)) {
                String bodyStr = BaseUtils.bomAwareToString(((SSEHttpResponseHandler) context.httpResponseHandler()).getErrorBodyByteArrayUnsafe(), null);
                if (httpResponse.getHeaderValue("content-type").equals("text/event-stream")) {
                    Event errorEvent = Event.parse(bodyStr);
                    if ("error".equals(errorEvent.getEvent()) && !StringUtils.isEmpty(errorEvent.getData())) {
                        Object _body = ParseUtil.readAsJSON(errorEvent.getData());
                        Map<String, Object> err = CommonUtil.assertAsMap(_body);
                        errMsg.put("code", err.get("errorName"));
                        errMsg.put("message", "code: " + err.get("errorCode") + ", " + err.get("errorMessage") + " request id: " + err.get("requestId"));
                        errMsg.put("description", err.get("errorMessage"));
                        errMsg.put("data", err);
                    } else {
                        Object requestId = httpResponse.getHeaderValue("x-acs-request-id");
                        Map<String, Object> err = new HashMap<>();
                        err.put("RequestId", requestId);
                        errMsg.put("code", httpResponse.getStatusCode());
                        errMsg.put("message", bodyStr);
                        errMsg.put("description", "Not SSE style.");
                        errMsg.put("data", err);
                    }
                } else {
                    Object _body = ParseUtil.readAsJSON(bodyStr);
                    Map<String, Object> err = CommonUtil.assertAsMap(_body);
                    Object requestId = CommonUtil.defaultAny(err.get("RequestId"), err.get("requestId"));
                    errMsg.put("code", CommonUtil.defaultAny(err.get("Code"), err.get("code")));
                    errMsg.put("message", "code: " + httpResponse.getStatusCode() + ", " + CommonUtil.defaultAny(err.get("Message"), err.get("message")) + " request id: " + requestId);
                    errMsg.put("description", CommonUtil.defaultAny(err.get("Description"), err.get("description")));
                    errMsg.put("accessDeniedDetail", CommonUtil.defaultAny(err.get("AccessDeniedDetail"), err.get("accessDeniedDetail")));
                    errMsg.put("data", err);
                }
            } else if (!StringUtils.isEmpty(httpResponse.getBodyAsString())) {
                Object _body = ParseUtil.readAsJSON(httpResponse.getBodyAsString());
                Map<String, Object> err = CommonUtil.assertAsMap(_body);
                Object requestId = CommonUtil.defaultAny(err.get("RequestId"), err.get("requestId"));
                errMsg.put("code", CommonUtil.defaultAny(err.get("Code"), err.get("code")));
                errMsg.put("message", "code: " + httpResponse.getStatusCode() + ", " + CommonUtil.defaultAny(err.get("Message"), err.get("message")) + " request id: " + requestId);
                errMsg.put("description", CommonUtil.defaultAny(err.get("Description"), err.get("description")));
                errMsg.put("accessDeniedDetail", CommonUtil.defaultAny(err.get("AccessDeniedDetail"), err.get("accessDeniedDetail")));
                errMsg.put("data", err);
            } else {
                Object requestId = httpResponse.getHeaderValue("x-acs-request-id");
                errMsg.put("code", httpResponse.getStatusCode());
                errMsg.put("message", "code: " + httpResponse.getStatusCode() + ", request id: " + requestId);
                errMsg.put("description", "");
            }
            teaResponse.setException(CommonUtil.is5xx(httpResponse.getStatusCode()) ? new PopServerException(errMsg) : new PopClientException(errMsg));
        }
        return teaResponse;
    }
}

==> aliyun-gateway-pop-0.2.15-beta-sources.jar: com/aliyun/sdk/gateway/pop/interceptor/response/TeaResponseInterceptor.java <==
package com.aliyun.sdk.gateway.pop.interceptor.response;

import com.aliyun.core.http.HttpResponse;
import com.aliyun.core.logging.ClientLogger;
import com.aliyun.core.utils.AttributeMap;
import com.aliyun.core.utils.BaseUtils;
import com.aliyun.core.utils.ParseUtil;
import com.aliyun.core.utils.StringUtils;
import com.aliyun.sdk.gateway.pop.exception.PopClientException;
import com.aliyun.sdk.gateway.pop.exception.PopServerException;
import darabonba.core.RequestStyle;
import darabonba.core.TeaRequest;
import darabonba.core.TeaResponse;
import darabonba.core.interceptor.InterceptorContext;
import darabonba.core.interceptor.ResponseInterceptor;
import darabonba.core.sse.Event;
import darabonba.core.sse.SSEHttpResponseHandler;
import darabonba.core.utils.CommonUtil;

import java.util.HashMap;
import java.util.Map;

public class TeaResponseInterceptor implements ResponseInterceptor {
    private final ClientLogger logger = new ClientLogger(PopResInterceptor.class);

    @Override
    public TeaResponse modifyResponse(InterceptorContext context, AttributeMap attributes) {
        logger.verbose("HttpResponse process begin.");
        HttpResponse httpResponse = context.httpResponse();
        TeaRequest request = context.teaRequest();
        TeaResponse teaResponse = new TeaResponse();
        teaResponse.setHttpResponse(httpResponse);
        teaResponse.setSuccess(CommonUtil.is2xx(httpResponse.getStatusCode()));
        if (CommonUtil.isNot2xx(httpResponse.getStatusCode())) {
            Map<String, Object> errMsg = new HashMap<>();
            errMsg.put("statusCode", httpResponse.getStatusCode());
            if (context.httpResponseHandler() != null && request.style().equals(RequestStyle.SSE)) {
                String bodyStr = BaseUtils.bomAwareToString(((SSEHttpResponseHandler) context.httpResponseHandler()).getErrorBodyByteArrayUnsafe(), null);
                if ("text/event-stream".equals(httpResponse.getHeaderValue("content-type"))) {
                    Event errorEvent = Event.parse(bodyStr);
                    if ("error".equals(errorEvent.getEvent()) && !StringUtils.isEmpty(errorEvent.getData())) {
                        Object _body = ParseUtil.readAsJSON(errorEvent.getData());
                        Map<String, Object> err = CommonUtil.assertAsMap(_body);
                        errMsg.put("code", err.get("errorName"));
                        errMsg.put("message", "code: " + err.get("errorCode") + ", " + err.get("errorMessage") + " request id: " + err.get("requestId"));
                        errMsg.put("description", err.get("errorMessage"));
                        errMsg.put("data", err);
                    } else {
                        Object requestId = httpResponse.getHeaderValue("x-acs-request-id");
                        Map<String, Object> err = new HashMap<>();
                        err.put("RequestId", requestId);
                        errMsg.put("code", httpResponse.getStatusCode());
                        errMsg.put("message", bodyStr);
                        errMsg.put("description", "Not SSE style.");
                        errMsg.put("data", err);
                    }
                } else {
                    Object _body = ParseUtil.readAsJSON(bodyStr);
                    Map<String, Object> err = CommonUtil.assertAsMap(_body);
                    Object requestId = CommonUtil.defaultAny(err.get("RequestId"), err.get("requestId"));
                    errMsg.put("code", CommonUtil.defaultAny(err.get("Code"), err.get("code")));
                    errMsg.put("message", "code: " + httpResponse.getStatusCode() + ", " + CommonUtil.defaultAny(err.get("Message"), err.get("message")) + " request id: " + requestId);
                    errMsg.put("description", CommonUtil.defaultAny(err.get("Description"), err.get("description")));
                    errMsg.put("accessDeniedDetail", CommonUtil.defaultAny(err.get("AccessDeniedDetail"), err.get("accessDeniedDetail")));
                    errMsg.put("data", err);
                }
            } else if (!StringUtils.isEmpty(httpResponse.getBodyAsString())) {
                Object _body = ParseUtil.readAsJSON(httpResponse.getBodyAsString());
                Map<String, Object> err = CommonUtil.assertAsMap(_body);
                Object requestId = CommonUtil.defaultAny(err.get("RequestId"), err.get("requestId"));
                errMsg.put("code", CommonUtil.defaultAny(err.get("Code"), err.get("code")));
                errMsg.put("message", "code: " + httpResponse.getStatusCode() + ", " + CommonUtil.defaultAny(err.get("Message"), err.get("message")) + " request id: " + requestId);
                errMsg.put("description", CommonUtil.defaultAny(err.get("Description"), err.get("description")));
                errMsg.put("accessDeniedDetail", CommonUtil.defaultAny(err.get("AccessDeniedDetail"), err.get("accessDeniedDetail")));
                errMsg.put("data", err);
            } else {
                Object requestId = httpResponse.getHeaderValue("x-acs-request-id");
                errMsg.put("code", httpResponse.getStatusCode());
                errMsg.put("message", "code: " + httpResponse.getStatusCode() + ", request id: " + requestId);
                errMsg.put("description", "");
            }
            teaResponse.setException(CommonUtil.is5xx(httpResponse.getStatusCode()) ? new PopServerException(errMsg) : new PopClientException(errMsg));
        }
        return teaResponse;
    }
}
